==> PyDev-9.3.0.zip: org/python/pydev/refactoring/codegenerator/constructorfield/request/ConstructorFieldRequest.java <==
/******************************************************************************
* Copyright (C) 2006-2012  IFS Institute for Software and others
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Original authors:
*     Dennis Hunziker
*     Ueli Kistler
*     Reto Schuettel
*     Robin Stocker
* Contributors:
*     Fabio Zadrozny <fabiofz@gmail.com> - initial implementation
******************************************************************************/
/* 
 * Copyright (C) 2006, 2007  Dennis Hunziker, Ueli Kistler
 * Copyright (C) 2007  Reto Schuettel, Robin Stocker
 *
 * IFS Institute for Software, HSR Rapperswil, Switzerland
 * 
 */

package org.python.pydev.refactoring.codegenerator.constructorfield.request;

import java.util.List;

import org.python.pydev.parser.jython.SimpleNode;
import org.python.pydev.parser.jython.ast.factory.AdapterPrefs;
import org.python.pydev.refactoring.ast.adapters.IASTNodeAdapter;
import org.python.pydev.refactoring.ast.adapters.IClassDefAdapter;
import org.python.pydev.refactoring.ast.adapters.INodeAdapter;
import org.python.pydev.refactoring.core.request.IRefactoringRequest;

public class ConstructorFieldRequest implements IRefactoringRequest {

    public final List<INodeAdapter> attributeAdapters;
    public final int offsetStrategy;
    public final IClassDefAdapter classAdapter;
    private final AdapterPrefs adapterPrefs;

    public ConstructorFieldRequest(IClassDefAdapter classAdapter, List<INodeAdapter> attributeAdapters,
            int offsetStrategy, AdapterPrefs adapterPrefs) {
        this.classAdapter = classAdapter;
        this.attributeAdapters = attributeAdapters;
        this.offsetStrategy = offsetStrategy;
        this.adapterPrefs = adapterPrefs;
    }

    @Override
    public IASTNodeAdapter<? extends SimpleNode> getOffsetNode() {
        return classAdapter;
    }

    @Override
    public AdapterPrefs getAdapterPrefs() {
        return adapterPrefs;
    }

}

==> PyDev-13.1.0.zip: org/python/pydev/refactoring/codegenerator/constructorfield/request/ConstructorFieldRequest.java <==
/******************************************************************************
* Copyright (C) 2006-2012  IFS Institute for Software and others
*
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Original authors:
*     Dennis Hunziker
*     Ueli Kistler
*     Reto Schuettel
*     Robin Stocker
* Contributors:
*     Fabio Zadrozny <fabiofz@gmail.com> - initial implementation
******************************************************************************/
/* 
 * Copyright (C) 2006, 2007  Dennis Hunziker, Ueli Kistler
 * Copyright (C) 2007  Reto Schuettel, Robin Stocker
 *
 * IFS Institute for Software, HSR Rapperswil, Switzerland
 * 
 */

package org.python.pydev.refactoring.codegenerator.constructorfield.request;

import java.util.List;

import org.python.pydev.ast.adapters.IASTNodeAdapter;
import org.python.pydev.ast.adapters.IClassDefAdapter;
import org.python.pydev.ast.adapters.INodeAdapter;
import org.python.pydev.parser.jython.SimpleNode;
import org.python.pydev.parser.jython.ast.factory.AdapterPrefs;
import org.python.pydev.refactoring.core.request.IRefactoringRequest;

public class ConstructorFieldRequest implements IRefactoringRequest {

    public final List<INodeAdapter> attributeAdapters;
    public final int offsetStrategy;
    public final IClassDefAdapter classAdapter;
    private final AdapterPrefs adapterPrefs;

    public ConstructorFieldRequest(IClassDefAdapter classAdapter, List<INodeAdapter> attributeAdapters,
            int offsetStrategy, AdapterPrefs adapterPrefs) {
        this.classAdapter = classAdapter;
        this.attributeAdapters = attributeAdapters;
        this.offsetStrategy = offsetStrategy;
        this.adapterPrefs = adapterPrefs;
    }

    @Override
    public IASTNodeAdapter<? extends SimpleNode> getOffsetNode() {
        return classAdapter;
    }

    @Override
    public AdapterPrefs getAdapterPrefs() {
        return adapterPrefs;
    }

}
